==> nextcloud-app-mail-5.5.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/mn.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ажил",
    "Personal" : "Хувийн",
    "Later" : "Хойшлуулах",
    "Mail" : "шуудан",
    "Connecting" : "холбож байгаа",
    "Save" : "Хадгалах",
    "Connect" : "холбох",
    "Name" : "нэр",
    "Mail address" : "шуудангийн хаяг",
    "Password" : "нууц үг",
    "None" : "юу ч үгүй",
    "IMAP Port" : "интернет мессеж хандалтын протокол -ийн порт",
    "IMAP User" : "интернет мессеж хандалтын протокол -ийн хэрэглэгч",
    "IMAP Password" : "интернет мессеж хандалтын протокол -ийн нууц үг",
    "SMTP Host" : "Энгийн мэйл дамжуулах протокол-ийн хост",
    "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
    "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Signature" : "Гарын үсэг",
    "Go back" : "Буцах",
    "Cancel" : "болиулах",
    "Accounts" : "Accounts",
    "Add mail account" : "шуудангийн хаяг нэмэх",
    "General" : "Ерөнхий",
    "List" : "Жагсаалт",
    "Archive" : "архив",
    "Delete" : "Устгах",
    "Search" : "Хайх",
    "Send" : "илгээх",
    "Refresh" : "Сэргээх",
    "Ok" : "За",
    "Select account" : "Аккаунт сонгох",
    "Subject" : "Сэдэв",
    "Add attachment from Files" : "Файлаас хавсралт нэмэх",
    "Choose" : "Сонгох",
    "Confirm" : "Батлах",
    "Favorite" : "Дуртай",
    "Back" : "буцах",
    "Attendees" : "Оролцогчид",
    "Description" : "Тодорхойлолт",
    "Create" : "Үүсгэх",
    "Select" : "Сонгох",
    "Comment" : "undefined",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Remove" : "Устгах",
    "email" : "цахим шуудан",
    "Today" : "өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Choose target folder" : "Зорилтот хавтасыг сонгох",
    "Other" : "Бусад",
    "Forward" : "дамжих",
    "Translate" : "Орчуулга",
    "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
    "Download attachment" : "Татаж авах хавсралт",
    "Save to Files" : "Файлд хадгална",
    "Save all to Files" : "бүх файлыг хадгалах",
    "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
    "Move" : "Зөөх",
    "Remove account" : "Аккаунт устгах",
    "Folder name" : "Хавтасны нэр",
    "Saving" : "хадгаламж",
    "Show all folders" : "Бүх хавтас харуулах",
    "Loading …" : "Уншиж байна...",
    "Rename" : "Нэрлэнэ үү",
    "New message" : "шинэ зурвас",
    "Reply" : "хариулт",
    "Retry" : "Дахин оролдох",
    "Add" : "нэмэх",
    "Date" : "Он сар өдөр",
    "Tags" : "Tag-үүд",
    "Custom" : "Дурын",
    "Recipient" : "Хүлээн авагч",
    "Help" : "Туслах",
    "matches" : "тохируулах",
    "Actions" : "Үйл ажиллагаа",
    "delete" : "устгах",
    "Edit" : "Өөрчлөх",
    "Reset" : "тохируулах",
    "Client ID" : "Хэрэглэгчийн ID",
    "Host" : "хост",
    "Port" : "порт",
    "Certificate" : "Гэрчилгээ",
    "Submit" : "мэдэгдэх",
    "Shared" : "Түгээсэн",
    "Shares" : "Түгээлтүүд",
    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
    "All" : "бүх",
    "Drafts" : "ноорог",
    "Favorites" : "Онцолсон",
    "Inbox" : "ирсэн",
    "Junk" : "хэрэггүй",
    "Sent" : "илгээсэн",
    "Trash" : "хог",
    "Error loading message" : "алдаатай ачааллах зурвас"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/mn.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Ажил",
    "Personal" : "Хувийн",
    "Later" : "Хойшлуулах",
    "Mail" : "шуудан",
    "Connecting" : "холбож байгаа",
    "Save" : "Хадгалах",
    "Connect" : "холбох",
    "Name" : "нэр",
    "Mail address" : "шуудангийн хаяг",
    "Password" : "нууц үг",
    "None" : "юу ч үгүй",
    "IMAP Port" : "интернет мессеж хандалтын протокол -ийн порт",
    "IMAP User" : "интернет мессеж хандалтын протокол -ийн хэрэглэгч",
    "IMAP Password" : "интернет мессеж хандалтын протокол -ийн нууц үг",
    "SMTP Host" : "Энгийн мэйл дамжуулах протокол-ийн хост",
    "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
    "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Signature" : "Гарын үсэг",
    "Go back" : "Буцах",
    "Cancel" : "болиулах",
    "General" : "Ерөнхий",
    "Add mail account" : "шуудангийн хаяг нэмэх",
    "List" : "Жагсаалт",
    "Newest first" : "Шинийг урд нь",
    "Oldest first" : "Хуучныг урд нь",
    "Security" : "Хамгаалалт",
    "Archive" : "архив",
    "Delete" : "Устгах",
    "Search" : "Хайх",
    "Send" : "илгээх",
    "Refresh" : "Сэргээх",
    "Ok" : "За",
    "Select account" : "Аккаунт сонгох",
    "Subject" : "Сэдэв",
    "Add attachment from Files" : "Файлаас хавсралт нэмэх",
    "Choose" : "Сонгох",
    "Confirm" : "Батлах",
    "Favorite" : "Дуртай",
    "Back" : "буцах",
    "Attendees" : "Оролцогчид",
    "Description" : "Тодорхойлолт",
    "Create" : "Үүсгэх",
    "Select" : "Сонгох",
    "Comment" : "undefined",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Remove" : "Устгах",
    "email" : "цахим шуудан",
    "Today" : "өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Choose target folder" : "Зорилтот хавтасыг сонгох",
    "Other" : "Бусад",
    "Forward" : "дамжих",
    "Translate" : "Орчуулга",
    "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
    "Download attachment" : "Татаж авах хавсралт",
    "Save to Files" : "Файлд хадгална",
    "Save all to Files" : "бүх файлыг хадгалах",
    "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
    "Move" : "Зөөх",
    "Remove account" : "Аккаунт устгах",
    "Folder name" : "Хавтасны нэр",
    "Saving" : "хадгаламж",
    "Show all folders" : "Бүх хавтас харуулах",
    "Loading …" : "Уншиж байна...",
    "Rename" : "Нэрлэнэ үү",
    "New message" : "шинэ зурвас",
    "Reply" : "хариулт",
    "Retry" : "Дахин оролдох",
    "Add" : "нэмэх",
    "Date" : "Он сар өдөр",
    "Tags" : "Tag-үүд",
    "Custom" : "Дурын",
    "Recipient" : "Хүлээн авагч",
    "Help" : "Туслах",
    "matches" : "тохируулах",
    "Actions" : "Үйл ажиллагаа",
    "delete" : "устгах",
    "Edit" : "Өөрчлөх",
    "Reset" : "тохируулах",
    "Client ID" : "Хэрэглэгчийн ID",
    "Host" : "хост",
    "Port" : "порт",
    "Certificate" : "Гэрчилгээ",
    "Submit" : "мэдэгдэх",
    "Shared" : "Түгээсэн",
    "Shares" : "Түгээлтүүд",
    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
    "All" : "бүх",
    "Drafts" : "ноорог",
    "Favorites" : "Онцолсон",
    "Inbox" : "ирсэн",
    "Junk" : "хэрэггүй",
    "Sent" : "илгээсэн",
    "Trash" : "хог",
    "Error loading message" : "алдаатай ачааллах зурвас",
    "Accounts" : "Accounts"
},
"nplurals=2; plural=(n != 1);");
